=============================================
Integration and ODEs (:mod:`scipy.integrate`)
=============================================

.. module:: scipy.integrate


Integrating functions, given function object
============================================

.. autosummary::
   :toctree: generated/

   quad
   dblquad
   tplquad
   fixed_quad
   quadrature
   romberg

Integrating functions, given fixed samples
==========================================

.. autosummary::
   :toctree: generated/

   trapz
   cumtrapz
   simps
   romb

.. seealso::

   :mod:`scipy.special` for orthogonal polynomials (special) for Gaussian
   quadrature roots and weights for other weighting factors and regions.

Integrators of ODE systems
==========================

.. autosummary::
   :toctree: generated/

   odeint
   ode
